#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bz2
version:              1.0.1.0
visibility:           public
id:                   bz2-1.0.1.0-2Qqybx8YLuTH2BEVaXzqAg
key:                  bz2-1.0.1.0-2Qqybx8YLuTH2BEVaXzqAg
license:              BSD-3-Clause
copyright:            Copyright: (c) 2020 Vanessa McHale
maintainer:           vamchale@gmail.com
author:               Vanessa McHale
synopsis:             Bindings to libbz2
description:          High-level bindings to libbz2 via ByteString
category:             Compression
abi:                  650da504f2ad26ba95f3b73c23fb7210
exposed:              True
exposed-modules:      Codec.Compression.BZip
hidden-modules:
    Codec.Compression.BZip.Foreign.Common
    Codec.Compression.BZip.Foreign.Compress
    Codec.Compression.BZip.Foreign.Decompress
    Codec.Compression.BZip.Common Codec.Compression.BZip.Unpack
    Codec.Compression.BZip.Pack

import-dirs:          /usr/lib/ghc-8.10.2/site-local/bz2-1.0.1.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/bz2-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/bz2-1.0.1.0
hs-libraries:         HSbz2-1.0.1.0-2Qqybx8YLuTH2BEVaXzqAg
extra-libraries:      bz2
depends:              base-4.14.1.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-bz2/html/bz2.haddock
haddock-html:         /usr/share/doc/haskell-bz2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

